@@ -1,24 +1,21 @@
-# -*- coding: utf-8 -*-
-
-import nose.tools
-
 expected_result = (
-    u'<paragraph>D.\xa0Lindley. <emphasis>Making Decisions</emphasis>. '
-    u'Wiley, 2nd edition, 1985.</paragraph>'
+    '<paragraph>D.\xa0Lindley. <emphasis>Making Decisions</emphasis>. '
+    'Wiley, 2nd edition, 1985.</paragraph>'
     )
 
+
 def test_install_example():
     result = []
 
-    ### example begin ###
-    import six
+    # example begin
+    import io
     import pybtex.database.input.bibtex
     import pybtex.plugin
 
     style = pybtex.plugin.find_plugin('pybtex.style.formatting', 'plain')()
     backend = pybtex.plugin.find_plugin('pybtex.backends', 'docutils')()
     parser = pybtex.database.input.bibtex.Parser()
-    data = parser.parse_stream(six.StringIO(u"""
+    data = parser.parse_stream(io.StringIO(u"""
     @Book{1985:lindley,
       author =    {D. Lindley},
       title =     {Making Decisions},
@@ -27,10 +24,10 @@ def test_install_example():
       edition =   {2nd},
     }
     """))
-    for entry in style.format_entries(six.itervalues(data.entries)):
+    for entry in style.format_entries(data.entries.values()):
         print(backend.paragraph(entry))
-    ### example end ###
+    # example end
         result.append(backend.paragraph(entry))
 
-    nose.tools.assert_equal(len(result), 1)
-    nose.tools.assert_equal(six.text_type(result[0]), expected_result)
+    assert len(result) == 1
+    assert str(result[0]) == expected_result
